summaryrefslogtreecommitdiff
path: root/w32/subproc/w32err.c
diff options
context:
space:
mode:
Diffstat (limited to 'w32/subproc/w32err.c')
-rw-r--r--w32/subproc/w32err.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/w32/subproc/w32err.c b/w32/subproc/w32err.c
index 8abd75b..afe7668 100644
--- a/w32/subproc/w32err.c
+++ b/w32/subproc/w32err.c
@@ -2,7 +2,7 @@
#include "w32err.h"
/*
* Description: the win32 version of perror()
*
* Returns: a pointer to a static error
*
@@ -10,7 +10,7 @@
* comp.os.ms-windows.programmer.win32
*/
char *
-map_win32_error_to_string (DWORD ercode) {
+map_windows32_error_to_string (DWORD ercode) {
/* __declspec (thread) necessary if you will use multiple threads */
__declspec (thread) static char szMessageBuffer[128];
@@ -2,7 +2,7 @@
#include "w32err.h"
/*
- * Description: the win32 version of perror()
+ * Description: the windows32 version of perror()
*
* Returns: a pointer to a static error